
# q-expansion of newform 8036.2.a.s, downloaded from the LMFDB on 10 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 8036
weight = 2
poly_data = [9, 204, 1130, -2276, -18823, 34656, 37544, -84720, -21992, 82500, -220, -40524, 4748, 10948, -1934, -1644, 348, 128, -30, -4, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-4, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[59952362841513, 738083784597603, -196305191328821, -13852123920661924, 20402313321661661, 28198262762586312, -54976710977041287, -17304021386138605, 55269502351641049, 811667273331286, -27567693836690814, 3042707531442513, 7513711673122948, -1304931363722533, -1134655223791407, 238604415918489, 88680236252730, -20725264188092, -2778645197913, 693771077180], 8907432980628], [[190983464209108996263, 1555738005610136792040, -2950763457356350118969, -27515570123960339467871, 53967376288662842383274, 55417302249307152484678, -133301820620661470919197, -31996738533222421425408, 129922976197309212858705, -1268832263838809426215, -63775711863953965507911, 7637148660948016713900, 17214742740867450156004, -3055149489179038791221, -2583040292296088360850, 547064973518762056275, 200987274480806224623, -47074158679250201267, -6277851071446228846, 1567892632533415234], 7045699320779922348], [[237506550933062053047, 2351603977580673921478, -3540129341608367956689, -41370391953693733063937, 76448600437103562826964, 82085159614420114983234, -192459021916121267807269, -46054021734106426917342, 189167220552118841239433, -3140475534235154283977, -93326413146857308210869, 11815139014102216431238, 25275099625931947407732, -4630220852871028587469, -3801108458647015368204, 822244089607423348755, 296231174702212346977, -70424247764763687101, -9262887357902091940, 2338757660528812226], 7045699320779922348], [[620836439810025, 7723657414763231, -1309162504591808, -145789349517861572, 202658302419133080, 305071323257237295, -547047554161970435, -201766431641702593, 548751658773871214, 26102191633898274, -272988213285828381, 24114490412599688, 74233650073598569, -11748441413484831, -11189902694968197, 2229477793619106, 873381091267388, -197062564273797, -27339265673408, 6661373649057], 8907432980628], [[97226989580590920354, 1234511067892056717935, 137683984888334896715, -23837476286048645159857, 31172753632958704540280, 50327088938842591365967, -85783168225253530008394, -34029275141695079410549, 86537534252271920654531, 5221070179901194950473, -43154858634515689790568, 3498116413657850939414, 11749994362571690048087, -1805440454952041490734, -1772518274441041104831, 347664092105664073677, 138415002843547076609, -30930718070891675108, -4334271434248616952, 1049275988912470441], 1006528474397131764], [[606826360165697573025, 8395092563731168662665, 1023954424120529904920, -165493117300867307298002, 223334005665434926549898, 347741351999178390256559, -614376030427052055814071, -230588328077451908360595, 619876660982428449866914, 30268230823871797593612, -309205145409647896750815, 27270563865313329311810, 84209031937717862545217, -13339100027251658888871, -12705398753421574017087, 2533932755487489006282, 992270980545485712530, -224074168773683551559, -31073635796039525650, 7576293982927979121], 7045699320779922348], [[392584122713171677173, 4967650318979614979306, -113306502518376301934, -90208099965535405712597, 118753928893976335890255, 188504634894224254795827, -324232804881156119466287, -125963171001350030109214, 326510789581180900501616, 18087044949039785162649, -162744505113663406493844, 13746983099618899161683, 44305336615419018612667, -6916239982613718566301, -6683420464723393238238, 1322869278130680137994, 521906431334303239643, -117320671722447788928, -16342846128512544173, 3972783117852940809], 3522849660389961174], [[-221061471807410959458, -2586400883220466564331, 517517724798107266852, 46575172685757514399803, -62888363036257849808159, -97578804334811055019104, 169432892648625526742675, 65568896606482854054425, -169854154542396568640853, -9732855884360263281280, 84464400288516335583243, -6956162240324603946659, -22962070603119437409617, 3543492889243349642386, 3460621390478264793615, -680096131542676025598, -270070665887929370564, 60415489542289066625, 8453306354806390649, -2047786292360142275], 1761424830194980587], [[-667661155757941536921, -8943772883317561833176, -880481015365818753984, 180338782805028994078333, -246474731929496125697395, -378819093668096210188203, 676734395670792749969903, 249783826314754461858204, -682452603951447075395134, -31116542935035778457819, 340365600693759113900646, -30703096120479886653617, -92690601820563143085051, 14807867321195626880525, 13984839560922314660460, -2802339477585508903152, -1092181398511623458951, 247380582079000993072, 34202040308351693999, -8356272662031765421], 7045699320779922348], [[1039311719576074586769, 11973135027759598136281, -5004868760721322981926, -225340677579528815198014, 333187098654750974129600, 467029295366688741017921, -886587875671824490647875, -299668100923119368276203, 885892877952153906591132, 28483713793780474325016, -440051048998962173817801, 42952487320825958297536, 119580968135206563719079, -19652386941621891075063, -18018706532048828189043, 3665451754025270244468, 1406026625803290483046, -321427966399360503593, -44004533606033770380, 10817735530643672823], 7045699320779922348], [[-508723097353615002549, -6622263148757199924236, -395578244725691148738, 129044554135267262643513, -172340908041091230121837, -272203242371124194650313, 472103252678673209814171, 182985431498476594699216, -475532953075794779675528, -26798116659087406948195, 236964510849042737550060, -19717931987831196765635, -64491433648002404390229, 9993361151771601407425, 9725925495596380955028, -1915869049907838609096, -759339338545804496015, 170121063113279701288, 23774153729099490769, -5765110608764984219], 3522849660389961174], [[-562332436760355025320, -7045871191970967584026, -20762070898140250163, 137687461555365045233094, -187322137052218898966457, -289687900253439035789069, 511321403595229157488586, 193026483803831537370618, -514564778294223298658171, -26358642828281747248718, 256332262566733625164623, -22128310064864091219739, -69753480654678076097837, 10952270309572306681580, 10518852033194202600960, -2087033475527660694129, -821215965080328317242, 184817918043869208801, 25710747398443785873, -6253881503724915265], 3522849660389961174], [[1233943646077998910485, 16097180552095863216408, 343760481474573044810, -315556203763661953628365, 429824287705913693338525, 663248018168538332130329, -1174535280429699515543167, -440588282101994854095084, 1182522905208002117547780, 58703032263898179944719, -589251743429612557666656, 51513448344016378444467, 160381237404775884342221, -25306907459928782093989, -24189115890691711217376, 4812963651580171485534, 1888661390075851423815, -425833794628053440962, -59134751184578330885, 14402308926297643223], 7045699320779922348], [[1234585521558462095301, 15402396422972692780726, -3554413158860711081553, -304997202980737096627727, 444117927600826721299226, 635842430113801342281372, -1194877112155448350622119, -410474329960614160479102, 1197582146857521448758737, 41227112868720385687825, -595622318194356679148397, 57379737864677684063536, 161958144182482346030238, -26485294281914839965835, -24412967211259506148740, 4952712998950562047623, 1905411720410527343023, -434846673787457040185, -59642851508940305086, 14645155040509963820], 7045699320779922348], [[617682916703533320726, 8099183834371161701361, 321155306165435922256, -161021264521041724703129, 220873751730400091677289, 337911546657425909550568, -604220200791226407993500, -222874255585591719674739, 608602934352236377481532, 27923448863376964351637, -303357063011471710727439, 27275698837548390607893, 82584351503069563769488, -13173947522025534613790, -12457405771199322026019, 2494047510119311879458, 972757216930066495875, -220200766266302213723, -30459378048999778099, 7438783877591216548], 3522849660389961174], [[-699634305926123616771, -9235939572202007595577, -1221891996360336135274, 181302476507307694588730, -240832709198133636810616, -381979586086710828489095, 662877997391653078852985, 255826579517142651304643, -668728059025171509164860, -36486799032282948761686, 333503362373389497835863, -28224573672325185426058, -90809978718344201679229, 14168966215045114054639, 13699510172653880436333, -2709600815139216588042, -1069812371476842628582, 240323297279872800415, 33499956946277000400, -8138886928753770041], 3522849660389961174], [[829762774988511791610, 10524879908602517748106, -748060606226458740485, -199891469248486819547262, 272777471804394727207141, 419276455516957466764863, -741081009576028826055736, -278897838495269416179886, 744805250324323650729783, 37844023940778257308124, -370826360968046011930875, 32101655974673253786169, 100882261019315843361703, -15856792379304385164044, -15210701217109761007314, 3019802809987906445103, 1187394854241713040880, -267337054794349577899, -37172639749616416747, 9044475989189897959], 3522849660389961174]]

hecke_ring_character_values = None
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-1, 1, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0], [-1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, -1, 0, 0, 0], [0, 0, -1, 0, 1, 0, -1, 0, 0, 1, -1, -2, -1, -1, 1, 0, 1, 0, 0, 0], [0, -1, 1, 0, -1, 0, 1, 1, 0, 0, 1, 1, 2, 1, 0, 1, 0, 0, 0, 0], [0, 0, 0, 1, 1, 0, 0, 0, -1, 0, 0, -1, -1, 0, 0, 0, 0, 0, 1, 0], [0, 0, -1, 0, 0, -1, 1, -1, 0, -1, 0, -1, 0, -1, 1, -1, 0, 0, 0, 0], [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 1, -2, -1, -1, -1, 1, 2, 2, -2, 0, -1, 0, 1, 1, -2, 1, 0, 0, 1], [0, 0, 0, 0, -1, 0, 1, 1, 1, -1, -1, 0, 1, 1, 0, 0, 0, 0, 0, -1], [-2, 2, -2, -1, 1, 1, -2, 0, 0, 0, 0, -1, -2, -1, 0, 0, -1, 1, 1, 0], [0, -1, -2, 0, -1, 0, -1, 1, 0, 0, 0, -2, -1, -1, 0, -1, 1, -1, 1, -1], [-3, 0, 0, 1, 1, 1, 0, -2, -1, 1, 1, 0, 0, -1, 0, 1, 0, -1, 0, -1], [0, 2, 1, 0, 0, 0, -1, -1, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, -1, 0], [0, 1, 2, 0, -1, -1, 2, 0, 0, -1, 1, 1, 1, 1, -1, 0, -1, 0, -1, 1], [-3, 0, 1, 0, 1, 0, 0, 1, 1, 2, -1, 1, 1, 0, 1, 0, 0, 2, 0, 0], [-3, 0, 1, 1, 1, -1, 0, -1, -1, 2, -1, -2, 0, -1, -1, 0, 0, 0, 0, 0], [1, 1, 1, -1, -1, 0, 0, 2, 0, 0, -1, 0, 1, 1, 1, -1, 1, 1, 0, 1], [-4, 0, 0, 1, 0, -1, 0, 0, 0, 0, 0, -2, -1, 0, -1, -1, 0, -1, 0, 1], [-1, 0, 1, -2, -1, 1, 0, 0, -1, 1, 1, 0, 1, 0, 0, 0, 0, -1, -1, 0], [-4, 3, -1, 1, 2, 1, 1, -4, -1, -1, -1, -1, -1, -1, 0, 0, -2, 1, 0, -1], [1, -1, 4, 3, -1, 1, -2, 1, -2, 2, 1, 1, 1, 1, -2, 2, 0, -2, 0, 0], [-2, 0, -1, 2, 2, 0, 2, 0, -1, 0, 1, -1, -1, 0, -1, 1, 0, 0, 2, 0], [1, 0, 1, -1, -2, 0, -1, 3, 1, -1, 3, 4, 2, 2, 1, 0, 0, 0, -1, 3], [-2, 3, -1, 0, 0, 0, 2, -3, 0, -1, -1, -2, -1, -2, 0, 0, -1, 0, 0, -1], [3, 0, 1, -1, -1, 1, -1, -1, 0, 1, 1, 3, 1, -1, -1, 2, 0, 0, -2, -2], [-2, -1, 0, 2, 0, -2, 0, 1, 1, -1, 2, 1, -1, 0, -2, -1, 0, -1, 0, 1], [-1, 1, 0, 1, -3, -2, -3, 1, 1, -1, 1, -1, 1, 1, -1, -1, 2, -2, 0, 1], [-2, -1, 1, 0, 0, -2, 1, -1, 0, -1, 3, 1, 1, 0, 0, -1, 1, -1, -1, 2], [0, -2, -1, -2, -1, 1, 0, 3, 2, 1, -1, -1, 0, 1, 1, -1, 1, 0, 0, 1], [3, 2, 0, -2, -2, 0, -1, 2, 2, -1, -1, 2, 3, 2, 2, -1, 1, 1, -1, -1], [-5, 2, 0, 0, -1, 1, 1, 1, 1, -1, 1, 3, 1, 2, 0, 1, -1, 2, 0, 1], [2, 2, 0, 1, -2, 0, 2, -1, -1, 0, 1, 1, -1, -1, -3, 0, 0, -1, 0, -1], [4, 2, 0, -1, -1, 1, -1, -1, -1, -1, 0, 1, -2, -1, -2, 0, -2, 1, 0, -1], [-3, 1, 0, 0, -2, -2, 2, 2, 2, -2, -1, -2, 0, 2, 1, -3, 1, 0, 0, 0], [-1, 0, 3, 2, 1, -1, -4, 0, 0, 0, 0, 3, 1, 1, -2, 1, -1, 1, 0, 2], [-6, 1, 2, 0, 0, -2, 0, -2, 0, 0, 1, 1, 0, 0, -1, -1, 0, -2, -1, 3], [0, 0, 2, 0, -2, -1, 5, 0, 0, -2, 3, 2, 3, 2, 0, 0, -1, -1, -2, 2], [1, -2, 3, 4, 1, -2, -4, -2, -3, 2, 1, -2, 0, 1, -1, 2, 1, -3, 1, 0], [2, -2, 0, 1, 2, 0, 0, 1, -2, 2, -2, -4, -2, -1, 1, -1, 2, 0, 3, 0], [-2, -1, -1, -3, 2, 1, -3, 1, 2, 2, -3, -2, -1, -2, 2, -1, 1, 0, -1, -1], [-2, -4, 1, -1, 3, -2, -4, 1, 1, 3, 0, 0, -1, -1, 0, 0, 1, 0, 1, 1], [3, -3, 3, 2, -3, -1, 3, 2, 2, -1, 2, 0, 2, 4, -2, 0, 2, -1, 1, 1], [-2, -1, 3, 2, 1, -2, 0, 0, -1, 1, 0, -2, -1, 2, -3, 0, 1, -3, 1, 1], [-9, 1, 1, -2, -1, 0, 2, 1, 2, -2, 0, 3, 3, 1, 2, -1, -2, 4, 0, 1], [1, -3, 0, 3, -1, -2, 0, 1, 0, -1, 2, -2, 2, 1, -1, -1, 2, -3, 1, 1], [-4, -1, -4, -2, 3, -1, 2, -3, -1, 1, -2, -2, -2, -3, 2, -1, 0, 1, 1, -1], [-9, -1, 1, 3, -1, -1, 2, -4, -2, 0, 0, -2, 1, -1, 0, 0, -1, -1, 1, -1], [3, -1, 1, -2, 2, 3, 3, 4, 1, 0, -1, 1, 0, 2, 2, 0, -2, 4, 0, 1], [-2, -2, 1, -2, 1, 2, 0, 0, -1, 1, 1, 1, -1, 0, 2, 3, -1, 3, 0, 0], [-1, 2, 0, -2, 2, 4, -4, -2, 0, 2, -2, -1, -2, 0, 1, 2, -3, 2, 1, -2], [-1, -3, 2, 4, -2, 0, -2, 1, -1, 0, 1, 0, 0, 2, -3, 3, 1, -3, 0, 0], [-2, 2, -2, 2, 2, 0, -1, -1, -1, 0, -3, -6, -4, -3, 2, -2, 1, 0, 0, 0], [-1, 0, -4, -4, 2, 0, -1, -3, 1, -1, -3, -3, -3, 0, 3, -1, -1, 2, 1, -2], [1, 2, -3, -3, -1, 1, 4, 0, 1, -1, -1, -1, 0, -3, 4, -3, 2, 1, -1, -1], [-7, 1, 0, -1, 3, -1, 1, -1, -2, 0, 0, -3, -3, -2, 0, -2, -1, 1, 4, 0], [-1, -1, 4, 1, -2, 1, 2, -1, -1, -1, 3, 6, 3, 0, -3, 3, -3, 0, 0, 0], [-3, 6, -7, 0, 3, 3, -2, -4, -2, 2, -4, -8, -5, -6, 2, -1, 0, 1, 1, -4], [-1, -3, -3, -5, 3, 2, -2, 0, -1, 3, -2, -3, -2, -3, 2, 0, 0, -2, 1, -2], [-6, -2, 2, 0, -2, 1, 0, 2, 0, 0, 0, 1, 4, 3, -1, 3, 1, 0, 0, -2], [3, -3, 5, 3, -1, 2, 2, -4, -4, 2, 1, -2, 2, -1, -4, 2, -2, -2, 0, -4], [2, 2, 0, -1, 0, 3, 7, -2, 0, 0, -1, 4, 1, 0, 0, 2, -1, 3, 0, -2], [5, -3, 5, 1, 0, -1, 1, 3, 0, -2, 3, 5, 1, 2, -1, 0, -1, 0, 0, 4], [-4, -2, 0, 2, 2, -2, -11, -4, -2, 3, -1, -3, -3, -4, -3, 1, 0, -3, 2, -3], [-8, -3, -3, -2, 4, -2, -5, 2, 1, 3, -3, -6, -5, 0, 2, -1, 3, -2, 3, 0], [1, 3, -2, -1, 2, 2, -4, 3, -1, 3, -4, -7, -5, 0, 1, -1, 1, -2, 2, -2], [6, -2, 1, 2, -1, 0, 0, -1, 0, -2, 1, 2, -1, -1, -2, 2, 0, 0, 0, 1], [-6, 0, -1, -2, -2, -3, -6, 1, 2, 0, 1, 2, 0, -1, -3, 1, 0, -2, 0, 1], [2, 1, 0, -1, 3, 2, -3, -2, -1, 2, -5, 1, -3, -2, 3, 2, 0, -1, -1, -1], [-4, -4, 0, 1, 3, -1, -3, -1, 1, 3, -2, 2, 0, 1, 0, 1, 0, 0, 2, 0], [-2, 1, -1, -1, -4, -3, 7, 2, 3, -5, 3, 3, 3, 3, 2, -4, 0, 3, -2, 3], [-2, -1, -1, 0, -1, -2, 4, -2, 2, -3, 0, -4, 0, 1, 1, -6, 3, -1, -3, 1], [-7, 1, 3, 5, -3, -1, 0, 0, -1, -3, 2, 0, 2, 2, -3, 1, -1, -2, -1, 2], [-2, -1, 1, -2, -1, -2, 4, 2, 3, -1, -1, 3, 5, 3, 4, -1, -1, 4, -1, 1], [-5, 3, -2, 0, -3, 0, 7, 3, 2, -3, -1, 0, 2, 1, 1, -3, 2, 1, -3, 0], [3, -1, 4, 4, 1, 1, 1, 0, -5, 1, 3, 3, 4, 0, 0, 2, -1, 1, 0, 0], [-1, -1, -1, 1, 1, 3, 3, 0, -1, -1, 0, 6, 1, 1, -1, 3, -3, 5, -1, -1], [4, 4, -3, -3, -4, -1, -4, 1, 2, -2, -2, -3, 0, 2, 2, -4, 1, -1, 0, -2], [-2, -1, -3, -1, -1, 0, 0, 6, 2, -3, 0, 2, 0, 1, 2, -3, 2, 1, 0, 0], [5, 3, 0, -4, -4, 1, 4, 2, 2, -4, 0, 3, 2, 2, 2, -1, -1, 2, -1, -2], [3, 3, -1, 1, 4, -1, 2, -2, 0, 1, -1, -1, -3, -4, 2, -2, -2, 1, 0, 1], [2, -4, 0, -3, 3, 3, -1, -1, -1, 5, -4, -4, -4, -3, -2, 3, 0, -2, 2, -6], [1, -6, 4, 5, -2, 0, -1, 3, -1, 1, 1, 3, 1, 2, -2, 3, 3, -2, 1, 3], [-8, 1, -4, -3, 1, 1, -1, -2, 1, 1, -1, 1, -4, -2, 1, 0, -2, 2, 2, -1], [3, 3, -3, -4, 0, 3, -2, 1, -1, 0, -3, -6, -4, 0, 4, -2, 1, 2, -1, -2], [-3, 3, -4, -3, -3, 3, 1, -1, -2, 0, 1, 0, 3, -1, 0, 0, 0, 0, -2, -4], [1, 0, 3, 1, 0, 0, 1, 1, 0, 2, 1, 1, 1, -1, -2, 0, 0, -4, 0, 1], [5, 0, -6, -4, -3, -2, -4, 5, 3, -4, -2, -3, -4, 1, 2, -7, 4, -3, -1, 2], [2, -5, 4, 1, 3, -1, -1, -4, -5, 2, 3, 2, -1, -1, -1, 1, -1, -2, 1, 0], [-5, 0, 1, 3, 3, -3, 4, -6, -4, 0, 1, -5, -2, -3, -3, -2, 0, -5, 0, 0], [4, 1, 3, 4, -6, 0, 7, 0, 1, -5, 4, 2, 6, 4, -2, 0, -2, 0, -3, 1], [-6, 1, -1, 2, 5, 2, -4, 2, -3, 5, -4, -6, -5, -1, 1, 0, 3, -1, 3, -1], [3, 1, 1, -1, 0, 3, -3, -1, -2, 2, 1, 4, 1, -1, 1, 3, -1, 0, -1, -1], [2, 2, -6, -5, -1, 0, 4, 3, 4, -2, -3, -4, -3, 1, 6, -8, 1, -2, -1, 0], [-2, 1, 2, -3, -4, -1, 4, 0, 3, -5, 0, 4, 0, 2, -2, -1, -2, 4, -1, 0], [2, -1, 6, 2, -4, -1, -1, -1, -1, -5, 3, 3, 3, 4, -2, -1, -2, -1, 0, 3], [2, -7, 0, 1, 2, 0, -6, 0, -4, 3, 1, -4, -3, -2, -5, 2, 0, -1, 4, -3], [1, 3, -2, -9, 1, 3, -1, 2, 0, 0, 0, 6, 2, -3, 3, 3, -1, 2, 0, -3], [0, 0, 2, 1, 2, 1, -6, -1, -2, -2, 2, -1, -2, 0, -4, 0, -1, 0, 0, 2], [2, -6, 0, -3, -1, 0, 0, 4, 0, 1, 1, 2, 1, 1, -2, 0, -1, -1, -1, -1], [-7, -4, 2, -2, 1, 1, 5, 2, 2, 0, 4, 5, 1, 2, 1, 1, -2, 3, -1, 2], [10, -2, 4, 0, -2, 3, 4, 6, 2, 0, 4, 13, 6, 7, -1, 3, -3, 4, 0, 0], [-2, 0, 2, -3, 3, 4, 3, -1, -1, 1, -1, 5, 0, -3, 2, 2, -3, 3, -1, -2], [0, -5, -3, -4, -1, 2, -2, 4, 3, -1, -1, -1, 1, 3, 4, 1, -1, 3, -1, -1], [-9, 0, -5, -3, -2, 5, -1, 2, -1, 1, -2, -2, -1, -2, 0, 1, -2, 3, 2, -4], [-1, 3, -3, -2, 3, -1, -4, -6, 0, 3, -3, -6, -4, -3, 2, 0, -1, 0, 1, -5], [1, -2, 2, 4, 0, 2, 1, 7, 0, -1, 0, 4, 2, 2, 0, 2, -1, 0, 1, 2], [-7, -1, -3, -1, -1, -5, 0, -3, 2, -1, -2, -5, 0, -1, -2, -2, 0, -2, -2, 0], [-11, 4, 4, 6, 1, 0, 2, -9, -4, 0, 3, 0, 1, 1, -5, 4, -2, 1, 1, -1], [5, -6, 3, 1, -2, 1, -8, 1, -2, 4, -4, -5, 0, 0, 1, 4, 3, 0, 1, -1], [-6, -4, 4, 1, 1, -2, 1, -3, 0, 1, 6, 6, 4, 1, -2, 2, -1, 1, 0, 5], [-3, -2, 2, 4, 1, 2, -7, 1, -1, 3, 1, -2, -3, 0, -3, 6, -2, -2, 2, -1], [1, 3, -4, -1, 0, -2, 0, -1, -1, -1, 3, -2, 1, -1, -1, -1, 0, -5, 0, 0], [-4, -2, -6, -7, 1, 2, 0, 3, 3, -1, 0, 1, 2, -1, 5, -1, 0, 6, -1, -1], [0, 0, -5, -2, 5, 2, 0, -3, -1, 1, -3, -4, -2, -3, 5, -1, 2, 2, -1, -3], [-10, -3, 1, 2, 2, 1, -5, 0, -3, 3, 0, -2, -5, 0, -3, 2, 1, -2, 2, 2], [-1, -4, 1, 2, -2, 0, 0, 1, 2, 1, 2, 3, 1, 0, -1, 2, 0, -1, 2, -1], [-4, 3, -8, 3, 5, -1, -1, -5, 0, -1, -4, -6, -4, -3, 5, -2, 3, 0, 2, -1], [-4, 3, 2, 1, 4, -1, -1, -3, -3, 1, -1, 1, 1, -2, 2, -3, 2, 1, 0, 3], [0, -3, 3, 5, -4, -3, 5, 5, 2, -2, 4, 7, 5, 8, -3, 2, 1, -4, 0, 4], [-7, -3, 3, 5, 3, -2, 3, -4, -2, 0, 0, -6, -2, 0, -3, 1, 0, 1, 2, 4], [3, -10, 1, -3, -2, -2, -3, 3, 3, -1, 3, 0, 0, 2, -1, -2, 0, -6, -1, 1], [9, -2, 10, 2, -1, 0, -1, 5, 1, -1, 1, 8, 3, 3, -3, 0, 2, 2, -2, 5], [-1, 2, 1, 6, 4, 2, 1, 0, -1, 3, -2, 0, 0, 1, 1, 4, -2, 4, 4, 1], [1, -3, -1, 0, -2, 0, -5, 6, 5, 0, -1, -2, -4, 1, 1, -1, 1, -3, 1, 1], [-2, -3, 1, 0, 0, 6, 5, 2, -2, 2, 1, 4, 1, 2, -1, 2, 0, 3, 4, 0], [7, -5, -4, 0, 0, 2, 3, 8, 3, 0, 0, 1, -2, 2, 7, -1, 2, 1, 1, 3], [2, 4, -6, -4, -2, 3, 7, 0, 3, -1, -1, 0, -1, -2, 1, -3, -3, 5, -3, -1], [1, -6, -1, 1, 2, -1, -7, -1, -1, 4, -1, -3, 0, -2, 2, -1, 1, -4, 1, -2], [5, -7, -1, -1, -1, -3, -5, 0, -2, 2, 0, -2, -1, -3, 0, 0, 3, -7, -3, -1], [-7, -1, 2, -4, -1, 2, -3, -3, 0, 1, 0, 5, 0, -4, 1, 3, -3, 0, -1, -2], [12, -4, 4, -4, -3, -1, -5, 3, 3, -1, 2, 4, 1, 1, 0, -2, 3, -4, -5, 4], [-7, -2, -4, -3, 0, 0, -5, 0, -2, 0, -2, -3, -2, 0, 3, -2, 1, 3, -2, 3], [0, -7, 2, 3, 4, -5, 4, 1, 1, 0, 1, -7, 2, 3, 1, -2, 3, 3, 3, 3], [-2, 0, 9, 10, 0, 1, 5, -3, -4, 3, 0, 0, 3, 0, -5, 3, -3, 0, -1, 1], [-3, 7, -5, -4, -1, -3, -5, -3, 1, -1, -3, -5, -4, -3, 2, -4, 3, -1, -1, -1], [2, 1, -8, -3, 3, -3, -13, 2, -2, 4, -6, -17, -8, -7, 5, -10, 7, -3, 4, -3], [-1, 3, 3, 3, 0, -4, 5, -7, -1, -2, 4, 0, -1, 0, -4, 0, 0, -5, -3, 2], [-1, 1, -3, -2, -4, 0, 2, 4, 2, -3, -4, -4, 3, 2, 4, -6, 3, 5, 1, -1], [-7, -2, -2, 4, 5, -1, -7, -4, -3, 6, -5, -9, -5, -6, 2, 3, 3, -3, 2, -5], [11, -2, 1, -6, -4, 3, 3, 7, 4, 0, 0, 12, 2, 2, 4, 0, 0, 3, -1, 1], [-3, 5, 3, -1, -4, 1, 5, 7, 2, -5, 2, 4, 7, 6, 4, -4, 2, 2, -2, 5], [8, -2, 2, -2, -2, 3, 5, 2, 2, -2, 1, 9, 4, 2, 1, 5, -2, 4, 1, -2], [-6, 4, -4, -1, -1, 0, 4, 2, 1, -2, 0, 3, 1, -2, -2, -2, -2, 0, 1, -2], [-6, 8, 3, 1, 1, -1, 7, -5, -2, -1, -1, -1, 3, 1, 2, -2, -2, 3, -3, 1], [2, -5, -2, -5, 1, -2, 3, 2, 7, 0, -7, -3, -1, 0, 6, -4, 2, 1, -2, 0], [-3, 5, 7, 3, 0, -3, 2, 1, -2, -1, 4, 2, 1, 2, -4, 2, -4, 4, 2, 3], [-7, -3, -2, 4, 4, -5, -7, -5, -1, -1, 2, -4, -2, 0, -2, -4, 2, -5, 1, 3], [8, -8, 6, 5, 2, -3, 0, -2, -2, 2, 5, 5, 3, 2, -4, 2, -2, -1, -1, 4], [3, 4, 2, -4, 1, 5, 3, 0, -3, -1, 0, 6, 0, -2, -1, 6, -4, 4, -1, -2], [7, -5, 10, -2, -5, 2, 2, 4, 0, 1, 4, 10, 8, 1, -2, 4, -1, 0, -4, 0], [-3, 3, -5, -3, -5, -1, 3, 6, 2, -4, -3, -10, -4, 3, 1, -7, 4, 1, 2, 2], [-3, -5, 2, 3, 3, 0, -1, -1, -5, 1, 1, -3, 0, -1, -1, 2, -3, -1, 5, 0], [-5, 2, -4, -2, 2, 4, 0, -2, -4, 2, -6, -4, -4, -4, 3, 2, 0, 6, 0, -4], [-1, 7, -5, -5, 5, 3, -4, -4, -2, 4, -4, -3, -1, -7, 4, -2, -1, 3, 1, -5], [-3, -9, -3, -5, 2, -2, 1, 1, 3, 2, 0, 1, -2, -1, 3, 0, 0, -4, 1, 0], [-7, 9, -6, -2, -3, 0, 9, -3, 0, -4, 4, 2, 2, 1, 0, 0, -4, 1, -3, 0], [0, -5, 1, 8, 4, 0, -10, -3, -1, 1, -2, -2, -1, -2, -3, 4, -4, 2, 2, -3], [1, 0, -3, 0, 5, 7, -4, -1, 0, 6, -3, -1, -1, -4, 4, 3, -1, 4, 1, -2], [-4, 3, -5, -5, 0, 2, 0, 8, 5, 0, -5, 3, 0, 2, 7, -2, 1, 5, 1, 0], [11, -2, 6, -1, 4, 1, 4, -6, -6, 4, 3, 1, -2, -4, -4, 5, -3, -5, -3, -1], [-9, 6, 1, -2, 5, -2, 9, -5, 4, -1, 0, 4, 1, -1, 0, -1, -5, 7, -1, 1], [-10, 4, -11, -9, -1, -2, 6, 0, 3, -1, -2, -5, -2, -4, 5, -6, 4, 0, -2, -4], [-5, 6, -2, -2, 3, 1, 0, -5, -4, 0, -3, 5, -1, 0, 0, 1, -1, 3, 0, 0], [5, 0, 2, 6, 0, -1, 4, -2, -2, 2, 4, 1, 2, 2, 2, -3, -1, -2, 0, 0], [1, 2, 5, -4, -2, -3, 9, 4, 3, -3, 3, 12, 8, 6, 3, -2, 1, 3, -2, 3], [-11, -1, 5, -4, -4, 2, 4, -1, 0, -2, 4, 12, 8, 4, -3, 3, -4, 3, 1, -3], [4, 1, -4, -2, 0, 4, -3, -4, -1, -1, -2, -5, -6, -2, 1, 4, 0, 0, -1, -7], [-10, 6, -3, -4, -2, -3, 5, -1, 0, -3, 2, 3, 0, -3, -3, 1, -2, -2, 0, -2], [8, -3, 3, 2, -4, 4, -5, 1, -2, 2, 2, 7, 8, 2, 0, 5, -1, -1, -5, -3], [1, -8, 2, 0, -5, 2, 1, 9, 1, -3, 6, 5, 3, 9, -2, 3, 2, 2, 1, 6], [4, 5, 2, 3, -6, -3, -9, -5, 1, -3, 4, 3, 4, 0, -3, 0, 1, -1, -6, -1], [6, -3, 5, -4, 3, 1, 9, -3, -2, 4, 2, 5, 0, -2, 1, 1, -1, 1, -2, -2], [5, 2, 0, 0, 5, 3, 5, 5, 1, -1, 2, 10, -1, 5, 3, 0, -3, 8, 2, 6], [-6, 0, -1, 3, 1, 2, -2, -7, 0, 4, -2, 2, 2, -4, 3, 3, -1, -1, -3, -4], [-1, 1, -8, -2, 5, 1, 5, 5, 0, 2, -2, -9, -2, -2, 5, -3, 1, 6, 6, 0], [2, 4, -5, -5, 0, 3, 4, 2, 1, 1, -1, -3, 1, 2, 3, 3, -1, 1, -2, -3], [-9, 7, -5, 4, 1, -1, 2, 0, 7, -2, -5, -3, -2, 3, 2, -4, 1, 4, -1, 0], [7, 5, -2, -2, -7, 2, 1, 8, 5, -7, 5, 10, 6, 7, 3, -1, -2, 0, 1, 2], [4, 4, 6, 3, -5, 3, -2, 4, -1, 0, 6, 6, 6, 3, -5, 5, -3, -2, -2, 3], [4, 1, 2, 6, -3, -8, 1, 3, 4, -6, 8, 7, 5, 5, -2, -5, 1, -5, 1, 9], [-3, 3, -5, -1, 3, -1, 3, -12, -3, 0, 3, 4, -3, -5, 1, 1, -1, -4, 1, -2], [-11, 0, 1, -2, 3, -2, 0, -3, -1, 2, 1, 0, -1, -2, -3, 2, 0, 2, 0, -4], [0, 1, -1, -3, -4, -2, -1, 1, 2, -3, -1, 9, 6, 2, 3, -2, 0, 7, -5, 1], [16, -4, -4, 0, 1, -4, 5, 7, 3, -3, -2, 3, 1, 3, 7, -5, 4, 0, -1, 6], [-8, -2, -13, -4, 6, 2, -6, 5, 2, 4, -8, -14, -12, -7, 4, -6, 4, 2, 5, -3], [4, 1, -10, -3, 3, 2, -7, 1, -3, 1, -2, -6, -10, -1, 1, -2, 0, 2, 3, -3], [4, -6, 0, -3, -3, -3, 3, 1, 3, -3, 0, 8, 4, -1, -1, 1, 2, 3, -7, 1], [10, -2, -2, 3, -4, 2, -6, 6, 0, -1, 3, 0, -1, 6, 2, 2, 2, -3, 2, 2], [-4, -3, -5, -5, 3, 3, -5, 4, 1, 4, -3, 0, -3, -5, 4, 1, -3, 2, 2, -3], [-7, 4, 1, 5, 8, 3, -2, -1, -2, 6, -4, -4, -4, 0, 0, 3, -2, 4, 6, 4], [-2, 10, 12, 3, -3, 0, 7, -1, -4, -1, 6, 12, 8, 3, -6, 4, -5, 1, -2, 3], [5, 3, 0, -6, -7, 2, 0, 5, 1, -6, 6, 8, 6, 3, -2, -2, -4, -1, 0, 2], [-12, 6, 2, -1, -5, -1, -3, -6, 2, -2, 2, 0, 6, 1, -4, 3, -3, -2, -2, -1], [11, -2, 2, 8, 2, 0, 0, -4, -4, 2, 2, 0, 0, -5, -3, 4, 2, 2, -2, 2], [8, 0, -3, 1, 4, 5, 0, -3, -2, 4, 0, 7, 0, -6, -2, 6, -3, 2, 2, -6], [10, -14, 4, 1, -1, 0, -4, 6, -3, 4, 3, 1, 3, 1, -2, 6, 7, -5, -1, 0], [3, 6, 2, 6, -4, 3, 4, -2, 0, -2, 1, 2, 4, 2, -5, 2, -1, 2, -7, -1], [-3, -6, 1, 7, -2, -1, -15, 4, -1, 1, 2, -2, -1, 4, -6, 5, 0, -5, 2, -2], [-3, 1, -6, 0, -2, -5, -4, -9, -3, -1, 1, -7, -4, -5, -5, -1, 4, -9, 1, -3], [2, 3, 0, 3, 5, 4, -9, -4, -6, 4, 2, 3, -6, -2, -7, 8, -6, 0, 5, -1], [10, 5, -12, -7, -2, 1, 4, 4, 4, -2, -5, 0, -6, -1, 3, -6, 3, 2, -1, -1], [-10, 7, -3, 2, 2, -2, -3, -13, -6, 3, -3, -9, -4, -10, -3, 0, 2, -11, 1, -7], [-2, 4, -2, 3, -5, -1, 15, 11, 7, -5, 0, 4, 6, 9, 0, -1, 0, 7, 0, 2], [-3, 5, -2, -4, -3, -1, -5, 11, 6, -5, 6, 9, 6, 5, 8, -2, 2, 3, -2, 8], [3, 9, -5, -3, 4, 5, 5, -8, -7, -2, 3, 4, -2, -6, 3, 1, -4, 2, -2, -2], [-6, 3, -2, 0, 1, 1, -7, -2, -4, 4, 3, -2, 1, -4, -1, 4, 0, 1, 0, 1], [-4, -2, -2, -7, 5, -3, -10, 2, 2, 0, 1, 3, -1, 3, 0, -2, 1, -4, 2, 5], [8, 9, 1, -1, -1, -1, 7, -7, -1, -5, 1, 4, 0, 1, -1, -4, -6, 4, -1, -2], [13, 0, 7, 3, -1, 6, 2, -2, -3, 1, -2, 5, 4, 1, 0, 2, -6, 2, 0, -4], [4, 5, -7, -7, -6, 4, 9, 3, 4, -6, 3, 5, 0, 5, 6, -3, -2, 3, -1, 0], [-1, -4, 7, 2, -5, -2, 6, 8, 3, -2, 5, 8, 10, 9, -5, 4, -1, 3, -1, 6], [6, -5, 1, 2, 5, 3, -13, -2, 0, 2, -6, -1, -3, -1, 1, 2, 0, -2, 1, -2], [-19, 4, 5, 0, 7, 6, -3, -6, -4, 6, -3, 1, -6, -5, -6, 5, -6, 2, 0, -2], [-7, 0, -2, -11, 2, -2, 3, -6, -1, 1, -3, -3, -3, -5, 1, -4, -3, 3, 3, -3], [14, 4, 1, 5, -1, 1, -11, -4, -3, 2, 1, -1, -2, -3, -5, 3, 0, -8, -4, -2], [3, -4, 6, 4, -10, 0, 6, 3, 3, -7, 12, 11, 9, 5, -7, 0, 0, -4, -2, 7], [8, -4, -7, -5, -1, 1, -10, 6, 6, 0, -9, -8, -4, 1, 2, -2, 5, -5, -1, -4], [4, 11, -4, -5, 0, 0, -3, 0, -3, -3, -3, -5, -1, -4, 8, -3, 1, 4, -1, -1], [21, -3, 2, 3, -2, -2, -8, 0, -2, 1, 3, -4, 1, -1, -3, 5, 0, -6, -2, -2], [-2, -2, 3, -1, 2, 0, -7, 5, 3, 1, -4, 3, -5, 2, 1, -3, -2, 4, 2, 3], [2, -2, 2, 5, 3, -7, -3, -6, 1, 2, -2, 1, -3, 1, -3, -1, 3, -7, 0, 2], [-12, 2, -2, 5, 4, 1, 6, -5, 0, -4, 0, -7, -2, 2, 0, 0, -3, 6, 0, 4], [0, -6, 1, 4, -4, -3, 3, 2, -1, -1, 11, -2, 4, 3, -6, 0, -1, -4, 0, 8], [-2, -2, 7, 12, 6, -4, -5, -3, -3, 3, -1, 3, -3, 0, -5, 3, 1, -6, 5, 4], [-5, 5, -5, 1, 5, 7, 6, -5, -8, 5, -4, -7, -6, -7, -1, 2, 0, 4, 1, -5], [-5, -2, -7, -1, -4, -2, 11, 6, 7, -7, -8, -11, -3, 0, 9, -10, 5, 3, -2, 2], [0, 7, -8, 1, 1, -2, -5, -4, 2, -4, -12, -14, -8, -6, 5, -11, 4, 0, 0, -4], [2, 8, -7, -4, 2, 1, 6, 12, 6, -2, -8, -5, -6, 1, 2, -5, 1, 5, 4, 3], [-10, -4, 3, -3, 0, 0, 11, -8, -1, -3, 4, 3, 5, 2, 2, 4, -5, 1, -4, 0], [12, -4, -2, 0, -4, 5, 4, -2, 0, 0, 1, -2, 4, 2, 4, 0, 1, -4, -2, -1], [-5, -3, 7, 2, -6, -3, -9, -1, -6, -2, 8, 10, 6, 1, -2, 2, 2, -5, -1, 3], [-6, -2, 8, 0, -8, -4, -4, 7, 7, -6, 5, 11, 11, 8, 1, -3, 3, 1, -2, 8], [-2, 5, -5, 0, -2, 5, -1, 4, 3, -2, -2, 12, 2, 3, 5, 2, -3, 4, -1, 0], [-6, -7, 1, 3, 7, -3, 0, -6, -1, 5, -1, -5, -4, -3, -1, 0, -1, -2, 3, 5], [9, -1, 9, 13, 0, -4, 5, -4, -3, -5, 4, 7, -1, 2, -9, 3, -2, 0, 4, 1], [15, -7, 0, -3, -1, 6, 9, 5, 3, 1, 2, 8, 4, 3, 4, 3, -1, 5, 0, -3], [9, -18, 0, -3, 3, 1, 3, 6, 2, 4, -3, -3, 0, 2, 4, 2, 3, -2, -1, 0], [8, 7, -3, 4, -3, 4, -5, 1, 1, -2, -1, 3, -3, -1, -1, -1, 0, 3, -1, -2], [6, 2, 2, -6, 2, 6, 5, -6, 4, -2, -2, 12, 2, 2, 4, 4, -4, 8, -4, 0], [6, -4, 2, 1, -1, 0, -3, 6, 3, 4, 1, 0, 1, 5, -6, 2, 3, 3, -1, 0], [7, -2, 8, 4, 3, -1, -1, -8, -1, 6, 1, 6, 3, -2, -4, 5, -1, 3, 0, 3], [11, 11, 0, 0, 3, 4, -1, 1, -1, 1, -2, 5, -5, -5, -4, 3, -2, 0, 1, -2], [-8, 0, -4, 1, 3, -3, 19, -7, -3, -1, 6, -4, 2, -3, 3, -1, -2, -2, -1, 1], [-12, 8, -10, -6, 7, 3, 1, -10, -4, 3, -9, -13, -7, -8, -1, 1, 0, 1, 2, -9], [3, -6, 6, -4, -1, -2, -12, 7, -3, -2, 4, 7, 0, 1, 0, 1, 0, -6, -1, 8], [1, 2, 11, 3, -2, 8, 2, -4, -7, 4, 4, 13, 6, 1, -5, 12, -5, 4, -1, -2], [-2, -9, 13, 2, 7, 8, -15, -3, -7, 12, 1, 3, -3, -3, -6, 11, -4, -4, 2, -1], [-19, 9, 0, -5, -2, -2, 0, -7, 1, -5, -4, 4, -1, 0, -1, -3, -3, 2, -4, -2], [8, 5, 1, -13, -2, -1, -5, 3, 6, -4, 2, 3, 3, 4, 7, -4, 1, 4, -4, 4], [-5, -2, -1, -1, -6, -1, -3, 8, 4, -3, -6, -1, 2, 2, 3, -4, 2, -3, 0, -3], [0, 6, 6, 3, -1, 0, 4, 4, -1, 2, 3, 12, 1, 3, -7, 3, -3, -3, 0, 4], [-9, 7, -3, -3, -2, 3, 23, -8, -1, -5, 2, 6, 5, 0, 4, -1, -6, 5, -1, -4], [5, -5, -1, -5, -4, 0, 11, 2, 7, -1, 0, 5, 5, 5, -1, -4, 3, -1, -4, -2], [-2, -4, 4, 9, 10, -3, 0, -10, -4, 4, 4, 2, -3, -1, -7, 7, -4, -3, 1, 3], [1, -10, 0, 0, 3, -5, 2, 1, -1, 6, -2, -2, 0, -2, 0, 2, 5, -5, 1, 3], [6, -3, 1, 4, -12, -1, -3, 6, 5, -4, 6, 13, 9, 4, -1, -2, 2, -2, -11, 4], [-7, 1, -6, 0, 1, -4, 3, 2, 0, -2, -2, -4, -1, 1, 8, -6, 3, -1, 1, 2], [-4, -1, -5, -5, 0, 1, -3, 7, -2, 0, -2, -17, -7, -3, 7, -4, 5, 2, 1, 0], [14, 6, -1, 0, -3, 5, 3, -1, -1, -1, 0, 1, 2, 1, 3, 5, 2, 1, -3, 1], [0, -7, 8, 6, -2, -6, -3, -1, -5, 1, 7, 1, 5, -1, -2, 5, 1, -6, 4, 5], [-5, 1, -6, -10, 3, 0, 10, -1, 4, -5, 0, 0, -2, -1, 5, -3, -2, 5, -7, 3], [-3, 1, -5, -4, 3, -1, -7, -1, -1, -1, -1, 3, 0, -3, 8, 0, 5, 3, -1, -1], [-11, -2, -1, 3, 6, 0, -25, -4, -3, 5, 1, -5, -1, -3, -1, 4, 1, -4, 3, -5], [1, 0, -1, 1, -2, -4, 2, 1, 1, 2, -3, -1, -2, 2, 1, 0, 3, -1, -3, 6], [-7, -4, 2, 3, 7, -4, 15, -3, 1, -1, -4, -4, -2, -1, 2, -5, -1, 1, -2, 1], [-4, -2, -3, 10, 5, -2, 10, -3, 0, 0, -5, -8, -9, -3, 0, -4, 4, 1, 0, 5], [-6, 2, -3, 6, 3, 0, 5, -3, -1, -3, 3, 0, -8, -3, -2, 4, 0, -5, 4, 5], [9, -11, 14, 6, -4, 1, 8, -7, -3, -1, 6, 6, 6, 5, -6, 4, -8, 1, -1, 1], [3, 9, -6, 0, -3, -1, -1, -4, -2, 0, -5, -12, -7, -7, 0, -4, 2, -7, -2, -5], [5, 3, 0, 8, -4, -1, 11, -10, -6, -4, 6, -5, 0, -2, -4, 2, -5, -2, 1, -4], [9, -4, -5, 2, 1, -6, 7, -1, 2, -1, -1, -2, -6, -3, 1, -4, 2, -5, -1, 7], [-6, 4, -7, -8, 8, -3, 2, -9, 3, 3, -7, -9, -8, -8, -1, -3, -1, 1, 0, -1], [-15, 8, -2, -6, -4, -3, 2, 5, 7, -7, -4, -1, 0, 8, -2, -5, -2, 9, 1, 7], [15, -5, 0, -1, -2, 7, 4, 4, 0, 0, 3, -1, -1, 4, -1, 6, -2, -1, 7, -2], [8, -4, -7, 1, 1, -6, -12, -7, 4, -2, 0, -2, -4, -4, -1, -5, 3, -5, 0, 2], [-13, -7, -7, -5, 8, 2, 3, -10, -7, 7, -3, -15, -4, -10, 8, 2, -1, 4, 6, -5], [13, 12, -4, 5, -7, -1, 15, -6, 1, -9, 0, 2, 4, 2, 0, -5, -1, -2, -2, -3], [-11, 5, -9, 0, 3, 7, -2, 0, -2, -1, -2, -10, -4, -4, 0, 2, -2, 3, 5, -5], [8, -4, 0, 0, 8, 3, -4, -10, -6, 8, -2, 3, 2, -10, 1, 3, -5, 4, -1, -6], [6, -4, -3, -7, -5, -5, -10, 6, 3, 1, 2, -2, 1, 5, -2, 0, 2, -7, 2, 1], [9, 6, -9, -3, 8, 4, 1, -6, -2, 3, -6, -3, -5, -8, 4, 1, 3, 7, -1, -7], [5, 1, 1, -10, 2, 2, -9, 4, 1, 4, -2, 1, 0, 0, 3, 1, 4, 1, 1, 1], [-4, 20, -3, -2, -4, -5, -7, 7, 6, -6, 1, 1, 0, 5, 0, -9, -2, 1, 0, 4], [1, -7, 6, 3, 2, -3, -10, -1, -5, 3, -4, -7, -5, 3, 2, 2, 1, -4, 7, -3], [1, 14, -1, -4, 6, 6, 6, -8, -6, 4, -10, -2, -1, -10, 6, 1, -6, 10, -1, -8], [4, -8, 4, -2, 0, 7, 10, 6, 2, 0, 3, 8, 4, 6, -3, 5, -2, 2, 1, -2], [-13, 3, 7, 3, 2, 1, -15, -2, -5, 6, 5, 8, -2, -2, -7, 7, -6, -4, 2, 4], [13, -1, 4, 5, -3, 0, 0, 0, -3, 0, 1, -11, 1, 0, -1, 3, 3, -4, 1, 0], [11, -9, 7, -3, -6, -2, 1, 2, -3, -1, 6, -1, 7, 4, -3, 1, 4, -2, -4, -1], [8, 4, 7, 1, -7, 0, 10, 3, 0, -2, 5, 9, 6, 4, -8, 0, -7, 3, -3, 3], [14, 5, 1, -2, -6, 1, 1, 1, 2, -2, -3, -1, 4, 8, 4, -1, 4, -3, -4, 4], [4, -9, 14, 11, -4, -4, 1, 3, -5, 4, 2, 3, 10, 7, 0, 3, 1, -5, -2, 5], [1, 0, 9, -4, 2, -4, -9, -2, 1, 7, -3, -7, 0, -4, 4, -3, 0, -4, -2, 4], [2, 8, -1, 1, -3, -3, 16, -12, 1, -11, 2, 10, 2, -5, 0, -7, -5, 2, -7, -2], [0, -3, -3, 4, 2, 0, -6, -2, -1, 5, -5, -5, -1, -8, -2, 5, 1, 0, 3, -6], [-16, -1, 7, 5, 1, -6, 0, -3, 2, -1, 7, 4, 2, 3, -8, -1, -1, -1, -2, 7], [21, -8, 11, 9, -3, -1, 12, 4, -5, 0, 10, 18, 10, 5, -6, 1, 3, -3, 1, 2], [19, -14, 9, 0, -13, 0, -8, 9, 6, -6, 5, 11, 8, 11, -5, 4, 3, -6, -5, 2], [0, 1, -2, -7, -8, 3, 3, 9, 3, 0, 4, 4, 8, 2, 4, 1, 5, 2, -6, -2], [2, 5, 5, 8, 2, 2, -4, -3, 2, -1, -5, 0, -1, 4, 2, 0, 3, -3, -2, 1], [-4, -14, 5, -8, -4, -6, -2, 6, 3, 0, 5, 7, 3, -2, -1, -3, 2, -2, -2, 6], [-28, -1, -7, 2, 6, -3, -1, -8, 1, 7, -4, -20, -7, -8, -5, 0, 5, -4, 2, -6], [-4, -5, -3, 1, 7, -5, -15, -1, 0, 7, -4, -8, -5, -5, 2, -5, 4, -4, 2, -3], [5, 10, -6, -2, -1, -1, 0, -2, -1, -3, -1, 0, 1, 3, 3, -6, 5, 5, 1, -3], [-6, 7, -8, 3, 13, -2, -11, -3, -7, 9, -12, -16, -12, -8, 7, -5, 1, 1, 4, 1], [-9, -5, 7, 4, -11, -5, 8, -6, -6, -3, 9, -1, 6, -1, -9, 3, 1, -10, -8, 1], [14, 6, -4, -7, -3, 1, -11, -1, 0, 1, 1, 1, 3, -3, 6, 2, 2, 6, 1, -5], [5, -1, -3, 1, 3, 1, 23, 2, -2, 2, -2, -9, -2, -1, 6, -4, 1, 6, 1, 0], [-7, -11, 0, 0, -1, -1, 8, 4, -3, 1, 9, 4, 5, 0, 0, -2, 2, -5, 3, 0], [-3, 12, 0, 2, 4, 3, -5, -3, -3, -3, -3, -9, -7, -1, -2, 1, -4, 0, 3, -3], [-19, 2, -7, -4, 4, 3, 11, 1, 2, 1, -7, 4, -1, -4, 10, -7, 2, 9, 0, 0], [-3, 6, -1, 13, -1, -2, -2, 2, 2, -6, -3, -6, -5, 2, -3, -1, 4, 2, 5, -3], [-19, -2, 9, 4, 4, 0, -5, -2, 1, 1, 4, 12, -4, 1, -7, 6, -6, 0, 0, 1], [-10, -4, -1, -2, 4, -4, 11, 0, 6, -3, -1, 10, 6, 2, 8, 0, -3, 1, -6, 5], [-19, 8, 2, -7, 7, 6, 8, -6, -3, 7, -6, 0, -2, -9, 1, 6, -4, 7, -1, -3], [2, 2, 1, -2, 7, -4, -1, -2, 3, 11, -10, -11, -4, -5, 1, -1, 5, -5, -1, -5], [12, 2, 6, 5, 1, 4, -8, 4, 3, 2, -1, 3, 1, 3, 2, 2, 5, -1, -3, 4], [8, -2, 1, 7, -4, -2, -1, 10, 0, -3, 2, 6, 13, 4, 7, -3, 4, 5, -2, -3], [5, -1, -3, -11, -1, 1, 3, 6, 5, 4, 1, 8, -1, -1, 3, -5, 5, 1, 1, 4], [-10, 9, -4, -9, 1, -2, 1, 6, 10, -4, -8, -1, 0, 6, 7, -4, 0, 2, -3, 3], [-14, -6, 2, 6, -2, -10, 10, -10, -1, -7, -1, -14, 1, 2, 0, -6, -1, 0, -1, 1], [17, 8, 2, 1, -1, -1, -7, -5, -5, -3, 9, 6, 2, -2, -4, 1, 2, -11, -5, -2], [-13, 0, 7, 6, -2, 0, 1, 9, 4, 0, 5, 16, 4, 6, -6, 3, 0, 0, -4, 6], [11, -5, -5, -5, -3, 0, 6, 3, 3, 1, -1, -1, -1, -2, 0, -4, 9, -2, -1, 0], [-8, 2, -6, -1, 7, 4, -4, 5, -1, 1, -10, -11, -10, -1, -1, -1, 2, -2, 9, -1], [-2, -4, -5, -3, 1, -2, -5, 5, 4, -3, -1, -6, -7, 4, -5, -5, 5, -6, 6, 1], [-1, 6, -6, -4, -7, -4, 7, 3, 2, -6, 5, -3, 3, 5, -1, -2, 0, 3, 3, 1], [4, -9, 16, -2, -1, 6, -3, 8, -2, 4, 6, 10, 5, 8, -1, 8, 1, 3, 3, 4], [13, 1, 2, -2, -1, 2, 16, 2, 2, -3, -2, 12, -2, 5, -3, -2, -5, 2, -1, 1], [2, -11, 8, -4, -10, -4, 10, 8, 4, -2, 9, 7, 18, 6, -5, 3, -4, 4, -5, 3], [-9, -3, -4, -1, 4, -4, -16, 0, -1, 6, -4, -11, -4, -10, 0, 4, 4, -3, 2, -2], [-2, -15, -5, -10, 1, 1, 0, 9, 5, 2, 2, 1, 7, 1, 9, 4, 4, 1, -5, 0], [-20, 4, -4, 3, -1, -2, 7, -9, 3, -7, -5, -11, 0, 3, 6, -4, 5, -3, -5, 0], [17, -7, 3, 4, 7, 3, -9, 0, -10, 11, 3, 1, -4, -3, -2, 6, 3, -10, 3, -1], [-4, 1, -1, -2, 6, 0, 2, -1, -5, 5, -1, -2, -4, -6, 4, -1, -1, 0, 4, -3], [18, 2, 3, 2, 0, 2, 4, 4, -2, -2, -4, -12, -2, 2, 5, -4, -2, 2, 3, -3], [-8, 3, 13, 5, -5, -9, 0, 4, 1, -5, 5, 15, 10, 7, -1, -4, 1, -4, -6, 13], [2, -11, 3, -4, -2, -5, 5, 1, 7, -1, 0, 10, 11, 4, 8, -3, 0, 7, -6, 5], [16, 4, 7, 2, -2, -3, -16, 16, 2, 0, 6, 15, 6, 9, -6, 3, 3, 4, -2, 11], [-9, -5, 2, 0, 0, 2, 6, -3, -2, 1, 3, 4, 5, -2, -2, -4, 1, -2, 2, 1], [-15, -3, -4, -12, 2, 4, -5, 2, -4, 6, -1, -4, 2, -4, 3, 7, -3, -4, 2, -10], [7, 4, -5, 1, 5, 2, 8, 2, -4, 0, -7, -14, -9, 0, 7, -1, 0, 4, 1, 5], [13, -1, -4, 0, -5, -1, 1, 8, 4, -4, 2, 3, -5, 3, -5, 5, -2, -1, -1, 6], [19, -5, 7, 3, -4, 2, 12, 6, 5, -1, 3, 11, 11, 4, -1, 5, -4, -1, -5, 3], [0, 3, 0, -5, -8, 5, 8, 7, 3, -1, -4, 3, 5, 5, 3, 4, 5, 2, -4, -1], [4, -5, 6, 15, -3, -9, 5, 2, -2, 0, 10, 5, 6, 3, -11, 2, 1, -8, 0, 9], [-3, -4, 1, 12, -2, 2, 0, 0, -3, 1, 8, 0, 1, 4, -9, 6, -4, -10, 4, -1], [3, -8, 10, -1, -2, 0, -2, -10, -6, 10, 2, 8, 10, -6, -3, 6, -1, -1, -2, -7], [-10, -9, -3, -6, 4, -2, -9, -11, -2, 1, 7, 7, 0, -6, -3, 6, -6, -9, -3, -1], [-8, 2, -13, 1, -3, 2, 0, 0, 3, -3, -2, -13, -6, -2, 5, -2, 0, 2, 0, -2], [4, -12, 6, 3, 2, -5, -3, -13, 1, 1, 3, 0, -1, 1, -11, 3, 1, -7, 1, -4], [-10, 8, -6, 3, 13, -3, 6, -1, 0, 8, -1, -8, -7, -4, 3, 1, -2, 3, 6, 6], [-10, 7, -5, 4, -4, -3, 8, -3, -2, -7, -5, -7, -11, -3, -2, -9, 4, 4, 2, 0], [-9, 17, -4, -12, 1, 8, 18, -8, 2, 1, -4, 6, -4, -7, 2, -2, -9, 11, 0, -4], [-7, 5, -7, -9, 0, 13, 0, 0, 4, 1, -9, 1, -1, 0, 12, -4, -6, 11, -6, -1], [2, -3, 11, 3, 0, 1, -5, -7, -6, 4, 1, 18, 7, 1, -8, 15, -9, -4, 0, -1], [-3, -3, 4, 12, 5, -4, -11, -11, -3, 1, 2, 5, 0, -3, -6, 0, -1, -4, -4, 5], [22, -1, 2, -5, -4, 6, 0, 2, 4, -3, 3, 18, 7, 3, 5, 7, -3, 8, -11, 3], [-9, -7, -12, 1, 2, -5, -16, 2, 2, -4, -3, -7, -11, -4, -3, -4, 4, -5, 7, -2], [3, 3, 4, 10, 2, -2, 0, -3, -2, 0, 8, -2, 8, 0, -4, 10, -4, 6, 0, 2], [16, 4, 4, 5, 1, -2, 13, -2, -4, -6, 2, 3, -4, 0, -3, -4, -2, 2, 3, -3], [-3, -5, 1, 5, 2, 1, 7, 1, 5, 4, -4, 0, -2, 2, 1, -1, 5, 3, -1, 1], [-8, 8, 6, -11, -3, -2, 6, 0, 0, -4, 7, 8, 7, 6, -3, -1, -4, 4, 3, 1], [-9, -11, 5, 0, -3, 4, 1, 8, 5, 4, -8, 3, 1, 9, -4, 4, -2, 5, 1, 0], [5, 2, 12, -5, -7, -2, 1, -6, -2, -4, 12, 23, 8, -1, -6, 8, -4, -6, -7, 3], [0, -5, 7, 4, 3, 4, 1, -3, 0, 0, 2, 10, 2, 3, -4, 6, 0, 6, 5, -2], [-3, -11, -7, -2, -3, 1, 9, 8, 10, -2, -6, -8, -7, 3, 0, -2, 1, 1, 0, -4], [13, 4, 2, -6, -6, 2, 13, 7, 1, -7, 9, 21, 11, 4, 1, 6, -3, 5, -4, 1], [6, -10, 4, -1, -2, -2, 20, -4, -3, 3, 4, 0, 4, 0, -5, 3, -4, -8, 1, -3], [-5, 4, -1, 0, 4, 8, 4, -6, -3, 9, -7, 2, 3, -5, 7, 10, -1, 3, -1, -8], [0, -12, 8, 6, 6, 0, 10, 0, 4, 8, -6, -2, 0, -2, 0, 2, 0, -3, -2, -2], [-8, 4, 3, -1, -2, 0, -4, 8, -3, 3, 3, 8, -1, 1, -6, 4, 4, -4, -3, 3], [-17, 6, -10, -6, 2, -7, -2, 10, 10, -8, -4, -7, -8, 6, 6, -9, 3, 2, 8, 10], [3, 7, -3, -3, -4, 7, 9, -4, -1, 5, 2, 6, 7, 0, 4, 7, -2, 5, -1, -10], [-1, -6, -11, -8, 1, -4, -6, -5, 2, -2, -1, -8, -9, -5, -1, -8, 2, 2, 6, -2], [-4, 6, -6, -1, 7, 5, -9, -9, -3, 3, -8, -18, -10, -15, -3, 3, -2, -1, 7, -7], [6, -6, -7, 1, -3, 2, -5, 3, 3, -3, -4, 7, 2, -2, 8, 0, -1, 0, -6, -5], [15, -3, 3, 11, -4, -2, -5, 3, 4, -4, 3, 2, 9, 5, -1, 1, 0, -3, 0, 1], [-18, -7, -3, 3, 0, -8, 5, 5, 4, -6, 1, -1, 1, 4, 7, -4, 6, 0, 2, 3], [-3, 21, -3, -1, -6, -11, -4, -2, -1, -11, 6, 3, 3, 4, 0, -10, 6, -7, -4, 7], [-12, 2, 5, 3, -6, 4, -1, 0, -1, 0, 8, 8, 3, 2, -8, 8, -6, -3, 3, -2], [11, -10, 5, 2, 3, -1, -16, 14, 1, 9, -2, -11, -9, 2, -3, -1, 6, -3, 6, 3], [-20, -1, 5, -3, 7, 5, -5, -12, 0, 8, -6, -1, -2, -7, -9, 10, -7, -6, -2, -9], [13, 5, -14, 2, 6, 4, -8, -5, 1, -1, -1, 6, -8, -5, 0, 4, -1, -1, 0, -3], [10, 0, -2, 2, -9, 1, 5, 10, 7, -6, -1, -6, 5, 7, 10, -8, 5, 2, -8, 4], [5, -2, 6, 2, -10, -3, -6, 12, 4, -4, 10, 15, 18, 7, 0, 5, -1, 4, -5, 2], [-12, -4, -10, -1, -6, -6, 3, 2, 4, -3, -3, -7, 1, 0, 3, -13, 8, -5, -4, -3], [3, 2, 1, -2, 1, 7, 4, -5, 3, -6, -1, 12, -5, 5, -8, 7, -11, 3, 1, -2], [-1, 1, 7, 3, -3, -5, 2, -5, 0, -7, 8, 19, 6, 5, -3, -2, -6, -2, -5, 7], [12, 4, 6, -2, 0, 0, 3, 6, -3, 0, -2, -9, -6, 4, 1, -5, 5, 5, 1, 2], [-3, 14, -6, 9, 11, 4, 3, -11, -9, 7, -8, -10, -12, -8, 4, 5, -3, -3, 6, -3], [-14, -6, -3, -1, -3, 1, 4, -1, 5, -6, 1, 5, -1, 1, -5, -5, -6, 2, -1, 1], [-14, -2, -10, -21, 2, 2, -10, -3, 8, 2, -2, -2, -2, -5, 4, -1, 0, 3, -4, -3], [-19, 3, -9, 4, 5, -5, -6, -6, -5, -6, 0, -7, -7, -3, -3, 3, 0, -4, 9, -2], [-17, 11, -7, 3, 5, -4, 12, -6, 0, -4, -7, -7, -7, -1, 5, -5, 1, 3, 2, -3], [-11, 16, 1, -3, 1, -1, 4, 7, 8, -5, -5, 8, 4, 3, 8, -11, -6, 8, 1, 7], [-18, -12, 5, 6, 2, 3, 4, 2, -5, 4, 7, 0, -1, 3, 1, 10, -5, -7, 2, -1], [9, -8, -6, -2, 3, -6, 3, 4, 4, 6, -6, -18, -7, -1, 0, -4, 7, -7, 4, -4], [-8, -9, 6, 8, 9, 2, -6, -11, -4, 8, -1, 3, 5, 0, 0, 7, -4, 6, 1, -3], [3, -2, 0, 6, 5, -5, -23, -2, -4, 2, -5, -4, -11, -8, -8, 0, 2, -7, 0, 1], [10, 7, 2, 7, 0, 7, -16, -4, -6, 1, 3, 5, -3, -4, -1, 8, -8, 2, 1, 0], [-15, 18, -8, -13, 5, 2, 2, -11, -2, 4, -5, 0, -7, -11, -2, -3, -4, -2, -3, -4], [-25, 3, -13, -4, 7, -6, 0, -4, -5, -1, 0, -18, -11, -12, 0, -12, 5, -9, 9, -3], [-18, -4, -3, -15, -2, -4, -5, 3, 8, 1, -2, 2, 1, 2, 4, -4, 7, 2, -7, -1], [-19, 13, -2, 4, 7, 7, 4, -5, -2, 1, -3, -9, -6, 2, 2, 2, -3, 10, 4, 4], [-6, -3, -3, -14, -3, 6, -3, 13, 0, 0, -4, -2, 2, 1, 14, 0, 2, 11, -1, 0], [-17, -4, -1, -3, 8, -7, -7, -6, 1, 9, -7, -6, -10, -6, 3, -8, 7, -1, -2, 5], [4, 1, 8, 8, -3, 1, 8, 1, -2, 0, 4, -10, 6, 11, -5, 2, 4, 3, -2, 4], [7, 0, -6, -1, -2, -5, -19, 8, 4, 0, -3, -11, -3, 2, 5, -4, 10, -5, 5, 4], [-10, 6, 0, -1, 6, 6, -11, 4, 0, 1, -4, 4, -3, 1, 4, 2, -1, -2, 0, 2], [19, -22, 11, 13, 1, -2, -13, 11, -4, 3, 7, 0, 3, 8, -2, 1, 5, -7, -1, 10], [-22, 3, -6, -4, 2, -2, -16, -1, 9, -1, -9, -10, -6, 6, 1, -6, 3, 1, -1, 7], [11, -12, 1, 5, -4, -4, 3, 4, 1, -5, 5, 2, -1, 7, -2, 3, 7, -7, 0, 5], [-15, 6, -4, -11, -2, 1, -4, 5, 11, -6, 0, 0, 0, 7, 6, 1, 0, 3, -3, 5], [-12, -4, 1, 0, 0, -2, -1, 1, 5, 3, -9, 3, 5, 0, 11, 1, 1, 4, -7, -2], [-10, 4, -3, 0, -4, -4, 9, 9, 8, -6, -6, -9, 2, 4, 2, -9, -1, 7, 0, -1], [-13, -2, 6, -6, -4, -10, 14, 4, 7, -6, 5, 19, 7, 6, -4, -3, 0, 6, -5, 9], [11, 8, -3, -9, -4, 7, -17, 11, 4, 4, -6, -3, 1, 4, 6, 2, 5, 8, -2, 0], [-8, -6, -12, 0, 5, 1, -7, 1, 0, 3, -12, -15, -14, 0, 3, -3, 0, -2, 4, -2], [3, -4, 10, -4, 1, 0, 8, 5, 2, -4, 1, 7, 1, 3, 3, -8, -2, 5, -5, 9], [6, -4, -2, -5, -5, 3, -13, 10, -4, 9, 2, -2, 2, -1, -2, 4, 4, -12, 1, -3], [0, 5, 5, 6, -1, 1, 7, 4, -1, 1, 0, 1, -3, 5, 4, -1, 4, -5, 0, 5], [-6, -1, 2, -10, -1, 1, -11, 2, 8, -2, -5, 8, 5, 6, 3, -4, 2, -1, -4, -3], [5, 12, -15, -15, -3, 7, -8, 1, 6, 2, -7, -4, 0, -8, 12, -1, 4, 9, -8, -7]]
